: Use /bin/sh

# This script munches the Norwegian word-lists.
# Due to bugs in ispell spesial care has been taken.
# Warning:  Munching norsk.base takes 120M disk-space and a lot of time!

LANG="norsk"
EXT=".base"  # choose word-list to munch here.  outputfile=sourcefile.new
AFF=".aff"
NEW=".new"

SOURCE=${LANG}${EXT}
FROMAFF=${LANG}${AFF}
TOAFF=${LANG}${AFF}${NEW}
TARGET=${LANG}${EXT}${NEW}

# Ispell might core-dump in the last part of the MUNCHLIST-script if the whole
# dictionary is prosessed in one run.  More presicely if one have hash-overflows.
# So lets split it.
# No words starting with  does arise from prefix-flags, so we loose nothing.

grep "^[]"  ${SOURCE} | munchlist -v -c ${FROMAFF} -l ${TOAFF} > ${TARGET}.ae
grep "^[^]" ${SOURCE} | munchlist -v -c ${FROMAFF} -l ${TOAFF} > ${TARGET}.nae

# Merge the dictionaries and remove some redundant flags that MUNCHLIST
# does not find.
#
# The test at the end proves that it works.  No docs -)

cat  ${TARGET}.ae ${TARGET}.nae | \
sort "-t/" -u +0f -1 +0 | \
sed \
 -e "s/\(et\/.*M.*\)V/\1/" \
 -e "s/\(e\/.*M.*\)W/\1/" \
 -e "s/\(er\/.*I.*\)V/\1/" \
 -e "s/\(e\/.*B.*\)W/\1/" \
 -e "s/\(e\/.*\)C\(.*M\)/\1\2/" | \
sed -e N -e "s/^\([a-z]*\([^e][^r]\|[e][^r]\|[r][^e]\)\)\/\([A-Zt-z]*\)\\
\1e\/\([A-Zt-z]*\)R\([A-Zt-z]*\)$/\1\/\3\\
\1e\/\4\5/g"  -e "$ p" -e "$ d" -e P -e D | \
sed -e N -e "s/^\([a-z]*\)\(\/[AB]*\)E\(.*\)\\
\1er\/AI/\1\2\3\\
\1er\/AI/"  -e "$ p" -e "$ d" -e P -e D | \
sed -e N -e "s/^\([a-z]*\)\(mmet\/U\)\\
\1mne$/\1\2/"  -e "$ p" -e "$ d" -e P -e D > ${TARGET}

rm ${TARGET}.ae ${TARGET}.nae

# Lets compare the dictionaries to see if munchlist has done a good job.
# If it hasn't, see if ISPELL core-dumped.  If it did, try to split the
# dictionary differently at the top of this file.

munchlist -v -c ${FROMAFF} -l null.aff ${SOURCE} > ${SOURCE}.expanded
munchlist -v -c ${TOAFF}   -l null.aff ${TARGET}  > ${TARGET}.expanded

# Check if munchlist has done a good job.  Put result in ${LANG}.diff.

rm -f ${LANG}.diff
wc ${SOURCE}.expanded ${TARGET}.expanded > ${SOURCE}.diff
diff ${SOURCE}.expanded ${TARGET}.expanded >> ${SOURCE}.diff
rm ${SOURCE}.expanded ${TARGET}.expanded
